#
# spec file for package power-profiles-daemon
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           power-profiles-daemon
Version:        0.13
Release:        1.2
Summary:        Power profiles handling over D-Bus
License:        GPL-3.0-or-later
URL:            https://gitlab.freedesktop.org/hadess/power-profiles-daemon
Source:         %{url}/-/archive/%{version}/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE hold-profile-hardening.patch boo#1189900 -- Hardening of HoldProfile D-Bus method
Patch0:         hold-profile-hardening.patch

BuildRequires:  c_compiler
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  python3-dbusmock
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gudev-1.0) >= 234
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.114
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(umockdev-1.0)
Requires:       polkit

%description
power-profiles-daemon offers to modify system behaviour based upon user-selected
power profiles. There are 3 different power profiles: a "balanced" default mode,
a "power-saver" mode, and a "performance" mode.

%package doc
Summary:        Documentation for power-profiles-daemon
BuildArch:      noarch

%description doc
This package provides documentation for %{name}.

%prep
%autosetup -p1

%build
%meson \
	-Dsystemdsystemunitdir=%{_unitdir} \
	-Dgtk_doc=true \
	-Dtests=true \
	%{nil}
%meson_build

%install
%meson_install

%check
%meson_test

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc README.md
%{_bindir}/powerprofilesctl
%{_libexecdir}/%{name}
%{_unitdir}/%{name}.service
%{_datadir}/dbus-1/system.d/net.hadess.PowerProfiles.conf
%{_datadir}/dbus-1/system-services/net.hadess.PowerProfiles.service
%{_datadir}/polkit-1/actions/net.hadess.PowerProfiles.policy
%ghost %dir %{_localstatedir}/lib/%{name}

%files doc
%dir %{_datadir}/gtk-doc/
%dir %{_datadir}/gtk-doc/html/
%{_datadir}/gtk-doc/html/%{name}/

%changelog
* Wed Apr 26 2023 Enrico Belleri <idesmi@protonmail.com>
- Update to version 0.13:
  * Add support for the AMD P-State driver included in Linux 6.3
  * Fix mismatched profiles on some HP laptops and some
    miscellaneous bug fixes.
* Sun Jul  3 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.12:
  * Add support for the Intel "Energy Performance Bias" feature.
- Adapt to change of installed dbus configuration file
  [boo#1201125].
* Fri May 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.11.1:
  * Stops power-profiles-daemon from modifying the cpufreq driver
    when the user/administrator has chosen to disable the Intel
    P-State scaling governor (eg. forcing a passive operation
    mode).
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.11:
  * Fixes problems on Intel machines when the CPUs didn't support
    turbo at all, or the performance scaling governor was built as
    default in the kernel.
  * Add better end-user documentation.
  * Fixes in the command-line tool to not cause bug report tools
    to popup on not-uncommon errors.
  * Bug fix for running on some systems with controllable charge
    speeds.
- Drop fd1664dfe26f13f8c8cd7b44483cd872dfdede36.patch: upstreamed.
* Fri Nov 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add fd1664dfe26f13f8c8cd7b44483cd872dfdede36.patch: main: Error
  out on D-Bus communication errors (rh#2019536).
- Bump pkgconfig(polkit-gobject-1) BuildRequires version to 0.114.
  It's required for the g_autoptr() support we use.
* Fri Nov  5 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.10.1:
  * Fix bug in the authorisation codepath added in 0.10.0, where
    holding a profile could still succeed despite having sent a
    denial to the calling process.
  * Make pylint test optional.
- Drop f83685732b9dd8211840645ce76f43718b30218b.patch:
  incorporated upstream.
* Wed Oct  6 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.10.0:
  + This release adds authorisation checks for the profile holds
    and profile switching features of the backend daemon, through
    polkit. It is recommended that all distributions upgrade to
    this version as soon as possible.
  + This release also adds support for the "quiet" kernel platform
    profile used in some systems.
- Drop patches fixed upstream:
  + power-profiles-daemon-polkit-policy.patch
  + c9b646025d9f155509a6cda1c292bfd120daeb9e.patch
  + 20a2d7f7b80a1847f36236d40388f14ae99fa94b.patch
- Add f83685732b9dd8211840645ce76f43718b30218b.patch: build: Make
  pylint test optional. As power-profiles-daemon keeps getting
  built with slightly different versions of pylint with newer
  warnings, disable pylint test by default to avoid getting bug
  reports about it.
- Add hold-profile-hardening.patch: Hardening of HoldProfile D-Bus
  method (boo#1189900). Requested by openSUSE security team.
* Tue Sep 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add power-profiles-daemon-polkit-policy.patch -- Describe and
  set defaults for switching and holding power profiles; patch
  taken from upstream merge request (boo#1189900,
  glfo#hadess/power-profiles-daemon#47).
- Add Requires: polkit, needed at runtime after changes in
  permission handling due to above patch.
- Disable tests as they fail due to polkit changes from above
  patch not being integrated yet.
* Fri Sep 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Pass explicit systemdsystemunitdir=%%{_unitdir} to meson, ensure
  we have the correct systemd unitdir.
- Drop systemd and systemd-rpm-macros BuildRequires, not needed.
- Add check section and run meson_test macro, replace umockdev with
  pkgconfig(umockdev-1.0) BuildRequires.
- Add generic c_compiler BuildRequires as meson checks for it.
- Add upstream patches:
  + c9b646025d9f155509a6cda1c292bfd120daeb9e.patch:
    platform-profile: Add support for 'quiet' profile.
  + 20a2d7f7b80a1847f36236d40388f14ae99fa94b.patch: tests: Add
    tests for quiet profile support.
* Thu Aug 26 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
